from simpleicons.icon import Icon
merck_icon= Icon(
    title="Merck",
    slug="merck",
    hex="007A73",
    source="https://www.merck.com/",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Merck</title><path d="M6 6a6 6 0 0112 0zm0 12a6 6 0 016-6 6 6 0 01-6-6 6 6 0 000 12 a6 6 0 1012 0zm6-6a6 6 0 016 6 6 6 0 100-12c0 3.314-2.686 6-6 6"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
funimation_icon= Icon(
    title="Funimation",
    slug="funimation",
    hex="5B0BB5",
    source="https://www.funimation.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Funimation</title><path d="M12 0a12 12 0 1 0 12 12A12.001 12.001 0 0 0 12 0ZM7.428 16.06h9.188s-.449 3.278-4.601 3.278c-4.15 0-4.587-3.278-4.587-3.278z"/></svg>""",
    guidelines='https://brandpad.io/funimationstyleguide',
    license=None,
)



from simpleicons.icon import Icon
kotlin_icon= Icon(
    title="Kotlin",
    slug="kotlin",
    hex="7F52FF",
    source="https://www.jetbrains.com/company/brand/logos/",
    svg="""<svg role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24"><title>Kotlin</title><path d="M24 24H0V0h24L12 12Z"/></svg>""",
    guidelines='https://www.jetbrains.com/company/brand/',
    license=None,
)
